@@ -10,31 +10,31 @@
 #include "mipointrst.h"
 
 typedef struct {
-    Bool			SWCursor;
-    Bool			isUp;
-    Bool			showTransparent;
-    short			HotX;
-    short			HotY;
-    short			x;
-    short			y;
-    CursorPtr			CurrentCursor, CursorToRestore;
-    xf86CursorInfoPtr		CursorInfoPtr;
-    CloseScreenProcPtr          CloseScreen;
-    RecolorCursorProcPtr	RecolorCursor;
-    InstallColormapProcPtr	InstallColormap;
-    QueryBestSizeProcPtr	QueryBestSize;
-    miPointerSpriteFuncPtr	spriteFuncs;
-    Bool			PalettedCursor;
-    ColormapPtr			pInstalledMap;
-    Bool                	(*SwitchMode)(int, DisplayModePtr,int);
+    Bool SWCursor;
+    Bool isUp;
+    Bool showTransparent;
+    short HotX;
+    short HotY;
+    short x;
+    short y;
+    CursorPtr CurrentCursor, CursorToRestore;
+    xf86CursorInfoPtr CursorInfoPtr;
+    CloseScreenProcPtr CloseScreen;
+    RecolorCursorProcPtr RecolorCursor;
+    InstallColormapProcPtr InstallColormap;
+    QueryBestSizeProcPtr QueryBestSize;
+    miPointerSpriteFuncPtr spriteFuncs;
+    Bool PalettedCursor;
+    ColormapPtr pInstalledMap;
+    Bool (*SwitchMode) (ScrnInfoPtr, DisplayModePtr);
     xf86EnableDisableFBAccessProc *EnableDisableFBAccess;
-    CursorPtr                   SavedCursor;
+    CursorPtr SavedCursor;
 
     /* Number of requests to force HW cursor */
-    int				ForceHWCursorCount;
-    Bool			HWCursorForced;
+    int ForceHWCursorCount;
+    Bool HWCursorForced;
 
-    pointer			transparentData;
+    void *transparentData;
 } xf86CursorScreenRec, *xf86CursorScreenPtr;
 
 void xf86SetCursor(ScreenPtr pScreen, CursorPtr pCurs, int x, int y);
@@ -43,9 +43,8 @@ void xf86MoveCursor(ScreenPtr pScreen, int x, int y);
 void xf86RecolorCursor(ScreenPtr pScreen, CursorPtr pCurs, Bool displayed);
 Bool xf86InitHardwareCursor(ScreenPtr pScreen, xf86CursorInfoPtr infoPtr);
 
-CARD32 xf86ReverseBitOrder(CARD32 data);
-
 extern _X_EXPORT DevPrivateKeyRec xf86CursorScreenKeyRec;
+
 #define xf86CursorScreenKey (&xf86CursorScreenKeyRec)
 
-#endif /* _XF86CURSORPRIV_H */
+#endif                          /* _XF86CURSORPRIV_H */
