@@ -306,7 +306,7 @@ winCloseScreenPrimaryDD(ScreenPtr pScreen)
     pScreenInfo->pScreen = NULL;
 
     /* Free the screen privates for this screen */
-    free((pointer) pScreenPriv);
+    free((void *) pScreenPriv);
 
     return fReturn;
 }
