@@ -55,7 +55,7 @@ static void RootlessValidateGC(GCPtr pGC, unsigned long changes,
 static void RootlessChangeGC(GCPtr pGC, unsigned long mask);
 static void RootlessCopyGC(GCPtr pGCSrc, unsigned long mask, GCPtr pGCDst);
 static void RootlessDestroyGC(GCPtr pGC);
-static void RootlessChangeClip(GCPtr pGC, int type, pointer pvalue, int nrects);
+static void RootlessChangeClip(GCPtr pGC, int type, void *pvalue, int nrects);
 static void RootlessDestroyClip(GCPtr pGC);
 static void RootlessCopyClip(GCPtr pgcDst, GCPtr pgcSrc);
 
@@ -113,10 +113,10 @@ static void RootlessImageText16(DrawablePtr dst, GCPtr pGC, int x, int y,
                                 int count, unsigned short *chars);
 static void RootlessImageGlyphBlt(DrawablePtr dst, GCPtr pGC, int x, int y,
                                   unsigned int nglyphInit,
-                                  CharInfoPtr * ppciInit, pointer unused);
+                                  CharInfoPtr * ppciInit, void *unused);
 static void RootlessPolyGlyphBlt(DrawablePtr dst, GCPtr pGC, int x, int y,
                                  unsigned int nglyph, CharInfoPtr * ppci,
-                                 pointer pglyphBase);
+                                 void *pglyphBase);
 static void RootlessPushPixels(GCPtr pGC, PixmapPtr pBitMap, DrawablePtr dst,
                                int dx, int dy, int xOrg, int yOrg);
 
@@ -368,7 +368,7 @@ RootlessDestroyGC(GCPtr pGC)
 }
 
 static void
-RootlessChangeClip(GCPtr pGC, int type, pointer pvalue, int nrects)
+RootlessChangeClip(GCPtr pGC, int type, void *pvalue, int nrects)
 {
     GCFUNC_UNWRAP(pGC);
     pGC->funcs->ChangeClip(pGC, type, pvalue, nrects);
@@ -1356,7 +1356,7 @@ RootlessPolyText16(DrawablePtr dst, GCPtr pGC,
 static void
 RootlessImageGlyphBlt(DrawablePtr dst, GCPtr pGC,
                       int x, int y, unsigned int nglyphInit,
-                      CharInfoPtr * ppciInit, pointer unused)
+                      CharInfoPtr * ppciInit, void *unused)
 {
     GC_SAVE(pGC);
     GCOP_UNWRAP(pGC);
@@ -1419,7 +1419,7 @@ RootlessImageGlyphBlt(DrawablePtr dst, GCPtr pGC,
 static void
 RootlessPolyGlyphBlt(DrawablePtr dst, GCPtr pGC,
                      int x, int y, unsigned int nglyph,
-                     CharInfoPtr * ppci, pointer pglyphBase)
+                     CharInfoPtr * ppci, void *pglyphBase)
 {
     GCOP_UNWRAP(pGC);
     RL_DEBUG_MSG("polyglyph start ");
