@@ -51,7 +51,7 @@ static void XkbFakePointerMotion(DeviceIntPtr dev, unsigned flags, int x,
                                  int y);
 
 void
-xkbUnwrapProc(DeviceIntPtr device, DeviceHandleProc proc, pointer data)
+xkbUnwrapProc(DeviceIntPtr device, DeviceHandleProc proc, void *data)
 {
     xkbDeviceInfoPtr xkbPrivPtr = XKBDEVICEINFO(device);
     ProcessInputProc backupproc;
@@ -470,7 +470,7 @@ _XkbFilterISOLock(XkbSrvInfoPtr xkbi,
 }
 
 static CARD32
-_XkbPtrAccelExpire(OsTimerPtr timer, CARD32 now, pointer arg)
+_XkbPtrAccelExpire(OsTimerPtr timer, CARD32 now, void *arg)
 {
     XkbSrvInfoPtr xkbi = (XkbSrvInfoPtr) arg;
     XkbControlsPtr ctrls = xkbi->desc->ctrls;
@@ -540,7 +540,7 @@ _XkbFilterPointerMove(XkbSrvInfoPtr xkbi,
         xkbi->mouseKeysDY = XkbPtrActionY(&pAction->ptr);
         xkbi->mouseKeyTimer = TimerSet(xkbi->mouseKeyTimer, 0,
                                        xkbi->desc->ctrls->mk_delay,
-                                       _XkbPtrAccelExpire, (pointer) xkbi);
+                                       _XkbPtrAccelExpire, (void *) xkbi);
     }
     else if (filter->keycode == keycode) {
         filter->active = 0;
